@@ -89,6 +89,7 @@ class MultiButton(gtk.Button):
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher):
         abstract.LessonbasedGui.__init__(self, teacher)
+        self.m_key_bindings = {'backspace_ak': self.on_backspace}
         self.g_music_displayer = mpd.MusicDisplayer()
         self.practise_box.pack_start(self.g_music_displayer, False)
 
@@ -121,9 +122,9 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # statistics #
         ##############
-        self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
-                                   _("elembuilder"))
+        self.setup_statisticsviewer(statisticsviewer.StatisticsViewer, "")
     def new_question(self, widget):
+        self.g_answer_button_box.set_sensitive(True)
         self.g_answer.foreach(lambda w: w.destroy())
         self.m_users_answer = []
         self.m_t.new_question()
@@ -161,6 +162,7 @@ class Gui(abstract.LessonbasedGui):
                 self.g_backspace.set_sensitive(False)
                 if self.m_t.m_P.header.have_music_displayer:
                     self.run_exception_handled(self.show_answer)
+                self.g_answer_button_box.set_sensitive(True)
             else:
                 self.std_buttons_answer_wrong()
                 self.g_flashbar.flash(_("Wrong"))
@@ -183,12 +185,16 @@ class Gui(abstract.LessonbasedGui):
                     for btn in self.g_answer.get_children():
                         max_button_height = max(max_button_height, btn.size_request()[1])
                     self.g_answer_frame.set_size_request(-1, max_button_height)
-    def on_backspace(self, widget):
+    def on_backspace(self, widget=None):
+        if self.m_t.q_status in (self.m_t.QSTATUS_SOLVED,
+                                 self.m_t.QSTATUS_GIVE_UP):
+            return
         if self.m_users_answer:
             del self.m_users_answer[-1]
             self.g_answer.get_children()[-1].destroy()
         if not self.m_users_answer:
             self.g_guess_answer.set_sensitive(False)
+            self.g_backspace.set_sensitive(False)
     def add_element(self, widget, element):
         """
         Called when the user clicks a button to add another element.
@@ -212,6 +218,7 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P.header.have_music_displayer:
             self.run_exception_handled(self.show_answer)
         self.g_backspace.set_sensitive(False)
+        self.g_answer_button_box.set_sensitive(False)
     def on_start_practise(self):
         self.m_t.m_custom_mode = False # FIXME
         super(Gui, self).on_start_practise()
@@ -256,6 +263,7 @@ class Gui(abstract.LessonbasedGui):
         self.std_buttons_start_practise()
         self.show_hide_at_question_start_buttons()
         self.g_flashbar.flash(_("Click 'New' to begin."))
+        self.g_answer_button_box.set_sensitive(False)
     def on_end_practise(self):
         self.m_t.end_practise()
         self.std_buttons_end_practise()
